.. EZFF documentation master file, created by
   sphinx-quickstart on Wed Jan  9 10:52:51 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Code Documentation
==================

The following links provide a detailed description of individual classes and methods in the EZFF package.

.. toctree::
   :maxdepth: 1

   ezff
   ffio
   errors
   interfaces.vasp
   interfaces.qchem
   interfaces.gulp
   utils.reaxff
